# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['KubeNodePoolArgs', 'KubeNodePool']

@pulumi.input_type
class KubeNodePoolArgs:
    def __init__(__self__, *,
                 flavor_name: pulumi.Input[builtins.str],
                 kube_id: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 anti_affinity: Optional[pulumi.Input[builtins.bool]] = None,
                 autoscale: Optional[pulumi.Input[builtins.bool]] = None,
                 autoscaling_scale_down_unneeded_time_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 autoscaling_scale_down_unready_time_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 autoscaling_scale_down_utilization_threshold: Optional[pulumi.Input[builtins.float]] = None,
                 desired_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 max_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 min_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 monthly_billed: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 template: Optional[pulumi.Input['KubeNodePoolTemplateArgs']] = None):
        """
        The set of arguments for constructing a KubeNodePool resource.
        :param pulumi.Input[builtins.str] flavor_name: a valid OVHcloud public cloud flavor ID in which the nodes will be started. Ex: "b2-7". You can find the list of flavor IDs: https://www.ovhcloud.com/fr/public-cloud/prices/. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] kube_id: The id of the managed kubernetes cluster. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.bool] anti_affinity: should the pool use the anti-affinity feature. Default to `false`. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.bool] autoscale: Enable auto-scaling for the pool. Default to `false`.
        :param pulumi.Input[builtins.int] autoscaling_scale_down_unneeded_time_seconds: scaleDownUnneededTimeSeconds autoscaling parameter How long a node should be unneeded before it is eligible for scale down
        :param pulumi.Input[builtins.int] autoscaling_scale_down_unready_time_seconds: scaleDownUnreadyTimeSeconds autoscaling parameter How long an unready node should be unneeded before it is eligible for scale down
        :param pulumi.Input[builtins.float] autoscaling_scale_down_utilization_threshold: scaleDownUtilizationThreshold autoscaling parameter Node utilization level, defined as sum of requested resources divided by capacity, below which a node can be considered for scale down
               * `template ` - (Optional) Managed Kubernetes nodepool template, which is a complex object constituted by two main nested objects:
        :param pulumi.Input[builtins.int] desired_nodes: number of nodes to start.
        :param pulumi.Input[builtins.int] max_nodes: maximum number of nodes allowed in the pool. Setting `desired_nodes` over this value will raise an error.
        :param pulumi.Input[builtins.int] min_nodes: minimum number of nodes allowed in the pool. Setting `desired_nodes` under this value will raise an error.
        :param pulumi.Input[builtins.bool] monthly_billed: should the nodes be billed on a monthly basis. Default to `false`. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] name: The name of the nodepool. Warning: `_` char is not allowed! **Changing this value recreates the resource.**
        :param pulumi.Input['KubeNodePoolTemplateArgs'] template: Node pool template
        """
        pulumi.set(__self__, "flavor_name", flavor_name)
        pulumi.set(__self__, "kube_id", kube_id)
        pulumi.set(__self__, "service_name", service_name)
        if anti_affinity is not None:
            pulumi.set(__self__, "anti_affinity", anti_affinity)
        if autoscale is not None:
            pulumi.set(__self__, "autoscale", autoscale)
        if autoscaling_scale_down_unneeded_time_seconds is not None:
            pulumi.set(__self__, "autoscaling_scale_down_unneeded_time_seconds", autoscaling_scale_down_unneeded_time_seconds)
        if autoscaling_scale_down_unready_time_seconds is not None:
            pulumi.set(__self__, "autoscaling_scale_down_unready_time_seconds", autoscaling_scale_down_unready_time_seconds)
        if autoscaling_scale_down_utilization_threshold is not None:
            pulumi.set(__self__, "autoscaling_scale_down_utilization_threshold", autoscaling_scale_down_utilization_threshold)
        if desired_nodes is not None:
            pulumi.set(__self__, "desired_nodes", desired_nodes)
        if max_nodes is not None:
            pulumi.set(__self__, "max_nodes", max_nodes)
        if min_nodes is not None:
            pulumi.set(__self__, "min_nodes", min_nodes)
        if monthly_billed is not None:
            pulumi.set(__self__, "monthly_billed", monthly_billed)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if template is not None:
            pulumi.set(__self__, "template", template)

    @property
    @pulumi.getter(name="flavorName")
    def flavor_name(self) -> pulumi.Input[builtins.str]:
        """
        a valid OVHcloud public cloud flavor ID in which the nodes will be started. Ex: "b2-7". You can find the list of flavor IDs: https://www.ovhcloud.com/fr/public-cloud/prices/. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "flavor_name")

    @flavor_name.setter
    def flavor_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "flavor_name", value)

    @property
    @pulumi.getter(name="kubeId")
    def kube_id(self) -> pulumi.Input[builtins.str]:
        """
        The id of the managed kubernetes cluster. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "kube_id")

    @kube_id.setter
    def kube_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "kube_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="antiAffinity")
    def anti_affinity(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        should the pool use the anti-affinity feature. Default to `false`. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "anti_affinity")

    @anti_affinity.setter
    def anti_affinity(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "anti_affinity", value)

    @property
    @pulumi.getter
    def autoscale(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable auto-scaling for the pool. Default to `false`.
        """
        return pulumi.get(self, "autoscale")

    @autoscale.setter
    def autoscale(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "autoscale", value)

    @property
    @pulumi.getter(name="autoscalingScaleDownUnneededTimeSeconds")
    def autoscaling_scale_down_unneeded_time_seconds(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        scaleDownUnneededTimeSeconds autoscaling parameter How long a node should be unneeded before it is eligible for scale down
        """
        return pulumi.get(self, "autoscaling_scale_down_unneeded_time_seconds")

    @autoscaling_scale_down_unneeded_time_seconds.setter
    def autoscaling_scale_down_unneeded_time_seconds(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "autoscaling_scale_down_unneeded_time_seconds", value)

    @property
    @pulumi.getter(name="autoscalingScaleDownUnreadyTimeSeconds")
    def autoscaling_scale_down_unready_time_seconds(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        scaleDownUnreadyTimeSeconds autoscaling parameter How long an unready node should be unneeded before it is eligible for scale down
        """
        return pulumi.get(self, "autoscaling_scale_down_unready_time_seconds")

    @autoscaling_scale_down_unready_time_seconds.setter
    def autoscaling_scale_down_unready_time_seconds(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "autoscaling_scale_down_unready_time_seconds", value)

    @property
    @pulumi.getter(name="autoscalingScaleDownUtilizationThreshold")
    def autoscaling_scale_down_utilization_threshold(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        scaleDownUtilizationThreshold autoscaling parameter Node utilization level, defined as sum of requested resources divided by capacity, below which a node can be considered for scale down
        * `template ` - (Optional) Managed Kubernetes nodepool template, which is a complex object constituted by two main nested objects:
        """
        return pulumi.get(self, "autoscaling_scale_down_utilization_threshold")

    @autoscaling_scale_down_utilization_threshold.setter
    def autoscaling_scale_down_utilization_threshold(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "autoscaling_scale_down_utilization_threshold", value)

    @property
    @pulumi.getter(name="desiredNodes")
    def desired_nodes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        number of nodes to start.
        """
        return pulumi.get(self, "desired_nodes")

    @desired_nodes.setter
    def desired_nodes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "desired_nodes", value)

    @property
    @pulumi.getter(name="maxNodes")
    def max_nodes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        maximum number of nodes allowed in the pool. Setting `desired_nodes` over this value will raise an error.
        """
        return pulumi.get(self, "max_nodes")

    @max_nodes.setter
    def max_nodes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_nodes", value)

    @property
    @pulumi.getter(name="minNodes")
    def min_nodes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        minimum number of nodes allowed in the pool. Setting `desired_nodes` under this value will raise an error.
        """
        return pulumi.get(self, "min_nodes")

    @min_nodes.setter
    def min_nodes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "min_nodes", value)

    @property
    @pulumi.getter(name="monthlyBilled")
    def monthly_billed(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        should the nodes be billed on a monthly basis. Default to `false`. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "monthly_billed")

    @monthly_billed.setter
    def monthly_billed(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "monthly_billed", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the nodepool. Warning: `_` char is not allowed! **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def template(self) -> Optional[pulumi.Input['KubeNodePoolTemplateArgs']]:
        """
        Node pool template
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: Optional[pulumi.Input['KubeNodePoolTemplateArgs']]):
        pulumi.set(self, "template", value)


@pulumi.input_type
class _KubeNodePoolState:
    def __init__(__self__, *,
                 anti_affinity: Optional[pulumi.Input[builtins.bool]] = None,
                 autoscale: Optional[pulumi.Input[builtins.bool]] = None,
                 autoscaling_scale_down_unneeded_time_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 autoscaling_scale_down_unready_time_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 autoscaling_scale_down_utilization_threshold: Optional[pulumi.Input[builtins.float]] = None,
                 available_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 current_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 desired_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 flavor: Optional[pulumi.Input[builtins.str]] = None,
                 flavor_name: Optional[pulumi.Input[builtins.str]] = None,
                 kube_id: Optional[pulumi.Input[builtins.str]] = None,
                 max_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 min_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 monthly_billed: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 project_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size_status: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 template: Optional[pulumi.Input['KubeNodePoolTemplateArgs']] = None,
                 up_to_date_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 updated_at: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering KubeNodePool resources.
        :param pulumi.Input[builtins.bool] anti_affinity: should the pool use the anti-affinity feature. Default to `false`. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.bool] autoscale: Enable auto-scaling for the pool. Default to `false`.
        :param pulumi.Input[builtins.int] autoscaling_scale_down_unneeded_time_seconds: scaleDownUnneededTimeSeconds autoscaling parameter How long a node should be unneeded before it is eligible for scale down
        :param pulumi.Input[builtins.int] autoscaling_scale_down_unready_time_seconds: scaleDownUnreadyTimeSeconds autoscaling parameter How long an unready node should be unneeded before it is eligible for scale down
        :param pulumi.Input[builtins.float] autoscaling_scale_down_utilization_threshold: scaleDownUtilizationThreshold autoscaling parameter Node utilization level, defined as sum of requested resources divided by capacity, below which a node can be considered for scale down
               * `template ` - (Optional) Managed Kubernetes nodepool template, which is a complex object constituted by two main nested objects:
        :param pulumi.Input[builtins.int] available_nodes: Number of nodes which are actually ready in the pool
        :param pulumi.Input[builtins.str] created_at: Creation date
        :param pulumi.Input[builtins.int] current_nodes: Number of nodes present in the pool
        :param pulumi.Input[builtins.int] desired_nodes: number of nodes to start.
        :param pulumi.Input[builtins.str] flavor: Flavor name
        :param pulumi.Input[builtins.str] flavor_name: a valid OVHcloud public cloud flavor ID in which the nodes will be started. Ex: "b2-7". You can find the list of flavor IDs: https://www.ovhcloud.com/fr/public-cloud/prices/. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] kube_id: The id of the managed kubernetes cluster. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.int] max_nodes: maximum number of nodes allowed in the pool. Setting `desired_nodes` over this value will raise an error.
        :param pulumi.Input[builtins.int] min_nodes: minimum number of nodes allowed in the pool. Setting `desired_nodes` under this value will raise an error.
        :param pulumi.Input[builtins.bool] monthly_billed: should the nodes be billed on a monthly basis. Default to `false`. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] name: The name of the nodepool. Warning: `_` char is not allowed! **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] project_id: Project id
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] size_status: Status describing the state between number of nodes wanted and available ones
        :param pulumi.Input[builtins.str] status: Current status
        :param pulumi.Input['KubeNodePoolTemplateArgs'] template: Node pool template
        :param pulumi.Input[builtins.int] up_to_date_nodes: Number of nodes with the latest version installed in the pool
        :param pulumi.Input[builtins.str] updated_at: Last update date
        """
        if anti_affinity is not None:
            pulumi.set(__self__, "anti_affinity", anti_affinity)
        if autoscale is not None:
            pulumi.set(__self__, "autoscale", autoscale)
        if autoscaling_scale_down_unneeded_time_seconds is not None:
            pulumi.set(__self__, "autoscaling_scale_down_unneeded_time_seconds", autoscaling_scale_down_unneeded_time_seconds)
        if autoscaling_scale_down_unready_time_seconds is not None:
            pulumi.set(__self__, "autoscaling_scale_down_unready_time_seconds", autoscaling_scale_down_unready_time_seconds)
        if autoscaling_scale_down_utilization_threshold is not None:
            pulumi.set(__self__, "autoscaling_scale_down_utilization_threshold", autoscaling_scale_down_utilization_threshold)
        if available_nodes is not None:
            pulumi.set(__self__, "available_nodes", available_nodes)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if current_nodes is not None:
            pulumi.set(__self__, "current_nodes", current_nodes)
        if desired_nodes is not None:
            pulumi.set(__self__, "desired_nodes", desired_nodes)
        if flavor is not None:
            pulumi.set(__self__, "flavor", flavor)
        if flavor_name is not None:
            pulumi.set(__self__, "flavor_name", flavor_name)
        if kube_id is not None:
            pulumi.set(__self__, "kube_id", kube_id)
        if max_nodes is not None:
            pulumi.set(__self__, "max_nodes", max_nodes)
        if min_nodes is not None:
            pulumi.set(__self__, "min_nodes", min_nodes)
        if monthly_billed is not None:
            pulumi.set(__self__, "monthly_billed", monthly_billed)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if size_status is not None:
            pulumi.set(__self__, "size_status", size_status)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if template is not None:
            pulumi.set(__self__, "template", template)
        if up_to_date_nodes is not None:
            pulumi.set(__self__, "up_to_date_nodes", up_to_date_nodes)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="antiAffinity")
    def anti_affinity(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        should the pool use the anti-affinity feature. Default to `false`. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "anti_affinity")

    @anti_affinity.setter
    def anti_affinity(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "anti_affinity", value)

    @property
    @pulumi.getter
    def autoscale(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable auto-scaling for the pool. Default to `false`.
        """
        return pulumi.get(self, "autoscale")

    @autoscale.setter
    def autoscale(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "autoscale", value)

    @property
    @pulumi.getter(name="autoscalingScaleDownUnneededTimeSeconds")
    def autoscaling_scale_down_unneeded_time_seconds(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        scaleDownUnneededTimeSeconds autoscaling parameter How long a node should be unneeded before it is eligible for scale down
        """
        return pulumi.get(self, "autoscaling_scale_down_unneeded_time_seconds")

    @autoscaling_scale_down_unneeded_time_seconds.setter
    def autoscaling_scale_down_unneeded_time_seconds(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "autoscaling_scale_down_unneeded_time_seconds", value)

    @property
    @pulumi.getter(name="autoscalingScaleDownUnreadyTimeSeconds")
    def autoscaling_scale_down_unready_time_seconds(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        scaleDownUnreadyTimeSeconds autoscaling parameter How long an unready node should be unneeded before it is eligible for scale down
        """
        return pulumi.get(self, "autoscaling_scale_down_unready_time_seconds")

    @autoscaling_scale_down_unready_time_seconds.setter
    def autoscaling_scale_down_unready_time_seconds(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "autoscaling_scale_down_unready_time_seconds", value)

    @property
    @pulumi.getter(name="autoscalingScaleDownUtilizationThreshold")
    def autoscaling_scale_down_utilization_threshold(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        scaleDownUtilizationThreshold autoscaling parameter Node utilization level, defined as sum of requested resources divided by capacity, below which a node can be considered for scale down
        * `template ` - (Optional) Managed Kubernetes nodepool template, which is a complex object constituted by two main nested objects:
        """
        return pulumi.get(self, "autoscaling_scale_down_utilization_threshold")

    @autoscaling_scale_down_utilization_threshold.setter
    def autoscaling_scale_down_utilization_threshold(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "autoscaling_scale_down_utilization_threshold", value)

    @property
    @pulumi.getter(name="availableNodes")
    def available_nodes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of nodes which are actually ready in the pool
        """
        return pulumi.get(self, "available_nodes")

    @available_nodes.setter
    def available_nodes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "available_nodes", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation date
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter(name="currentNodes")
    def current_nodes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of nodes present in the pool
        """
        return pulumi.get(self, "current_nodes")

    @current_nodes.setter
    def current_nodes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "current_nodes", value)

    @property
    @pulumi.getter(name="desiredNodes")
    def desired_nodes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        number of nodes to start.
        """
        return pulumi.get(self, "desired_nodes")

    @desired_nodes.setter
    def desired_nodes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "desired_nodes", value)

    @property
    @pulumi.getter
    def flavor(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Flavor name
        """
        return pulumi.get(self, "flavor")

    @flavor.setter
    def flavor(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flavor", value)

    @property
    @pulumi.getter(name="flavorName")
    def flavor_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        a valid OVHcloud public cloud flavor ID in which the nodes will be started. Ex: "b2-7". You can find the list of flavor IDs: https://www.ovhcloud.com/fr/public-cloud/prices/. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "flavor_name")

    @flavor_name.setter
    def flavor_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "flavor_name", value)

    @property
    @pulumi.getter(name="kubeId")
    def kube_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the managed kubernetes cluster. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "kube_id")

    @kube_id.setter
    def kube_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "kube_id", value)

    @property
    @pulumi.getter(name="maxNodes")
    def max_nodes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        maximum number of nodes allowed in the pool. Setting `desired_nodes` over this value will raise an error.
        """
        return pulumi.get(self, "max_nodes")

    @max_nodes.setter
    def max_nodes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "max_nodes", value)

    @property
    @pulumi.getter(name="minNodes")
    def min_nodes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        minimum number of nodes allowed in the pool. Setting `desired_nodes` under this value will raise an error.
        """
        return pulumi.get(self, "min_nodes")

    @min_nodes.setter
    def min_nodes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "min_nodes", value)

    @property
    @pulumi.getter(name="monthlyBilled")
    def monthly_billed(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        should the nodes be billed on a monthly basis. Default to `false`. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "monthly_billed")

    @monthly_billed.setter
    def monthly_billed(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "monthly_billed", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the nodepool. Warning: `_` char is not allowed! **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Project id
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="sizeStatus")
    def size_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Status describing the state between number of nodes wanted and available ones
        """
        return pulumi.get(self, "size_status")

    @size_status.setter
    def size_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "size_status", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Current status
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def template(self) -> Optional[pulumi.Input['KubeNodePoolTemplateArgs']]:
        """
        Node pool template
        """
        return pulumi.get(self, "template")

    @template.setter
    def template(self, value: Optional[pulumi.Input['KubeNodePoolTemplateArgs']]):
        pulumi.set(self, "template", value)

    @property
    @pulumi.getter(name="upToDateNodes")
    def up_to_date_nodes(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Number of nodes with the latest version installed in the pool
        """
        return pulumi.get(self, "up_to_date_nodes")

    @up_to_date_nodes.setter
    def up_to_date_nodes(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "up_to_date_nodes", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Last update date
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_at", value)


class KubeNodePool(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 anti_affinity: Optional[pulumi.Input[builtins.bool]] = None,
                 autoscale: Optional[pulumi.Input[builtins.bool]] = None,
                 autoscaling_scale_down_unneeded_time_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 autoscaling_scale_down_unready_time_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 autoscaling_scale_down_utilization_threshold: Optional[pulumi.Input[builtins.float]] = None,
                 desired_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 flavor_name: Optional[pulumi.Input[builtins.str]] = None,
                 kube_id: Optional[pulumi.Input[builtins.str]] = None,
                 max_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 min_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 monthly_billed: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 template: Optional[pulumi.Input[Union['KubeNodePoolTemplateArgs', 'KubeNodePoolTemplateArgsDict']]] = None,
                 __props__=None):
        """
        Creates a nodepool in a OVHcloud Managed Kubernetes Service cluster.

        ## Example Usage

        Create a simple node pool in your Kubernetes cluster:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        node_pool = ovh.cloud_project.KubeNodePool("node_pool",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            kube_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            name="my-pool-1",
            flavor_name="b2-7",
            desired_nodes=3,
            max_nodes=3,
            min_nodes=3)
        ```

        Create an advanced node pool in your Kubernetes cluster:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        pool = ovh.cloud_project.KubeNodePool("pool",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            kube_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            name="my-pool",
            flavor_name="b2-7",
            desired_nodes=3,
            max_nodes=3,
            min_nodes=3,
            template={
                "metadata": {
                    "annotations": {
                        "k1": "v1",
                        "k2": "v2",
                    },
                    "finalizers": [],
                    "labels": {
                        "k3": "v3",
                        "k4": "v4",
                    },
                },
                "spec": {
                    "unschedulable": False,
                    "taints": [{
                        "effect": "PreferNoSchedule",
                        "key": "k",
                        "value": "v",
                    }],
                },
            })
        ```

        ## Import

        OVHcloud Managed Kubernetes Service cluster node pool can be imported using the `service_name`, the `id` of the cluster, and the `id` of the nodepool separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/kubeNodePool:KubeNodePool pool service_name/kube_id/poolid
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] anti_affinity: should the pool use the anti-affinity feature. Default to `false`. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.bool] autoscale: Enable auto-scaling for the pool. Default to `false`.
        :param pulumi.Input[builtins.int] autoscaling_scale_down_unneeded_time_seconds: scaleDownUnneededTimeSeconds autoscaling parameter How long a node should be unneeded before it is eligible for scale down
        :param pulumi.Input[builtins.int] autoscaling_scale_down_unready_time_seconds: scaleDownUnreadyTimeSeconds autoscaling parameter How long an unready node should be unneeded before it is eligible for scale down
        :param pulumi.Input[builtins.float] autoscaling_scale_down_utilization_threshold: scaleDownUtilizationThreshold autoscaling parameter Node utilization level, defined as sum of requested resources divided by capacity, below which a node can be considered for scale down
               * `template ` - (Optional) Managed Kubernetes nodepool template, which is a complex object constituted by two main nested objects:
        :param pulumi.Input[builtins.int] desired_nodes: number of nodes to start.
        :param pulumi.Input[builtins.str] flavor_name: a valid OVHcloud public cloud flavor ID in which the nodes will be started. Ex: "b2-7". You can find the list of flavor IDs: https://www.ovhcloud.com/fr/public-cloud/prices/. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] kube_id: The id of the managed kubernetes cluster. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.int] max_nodes: maximum number of nodes allowed in the pool. Setting `desired_nodes` over this value will raise an error.
        :param pulumi.Input[builtins.int] min_nodes: minimum number of nodes allowed in the pool. Setting `desired_nodes` under this value will raise an error.
        :param pulumi.Input[builtins.bool] monthly_billed: should the nodes be billed on a monthly basis. Default to `false`. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] name: The name of the nodepool. Warning: `_` char is not allowed! **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[Union['KubeNodePoolTemplateArgs', 'KubeNodePoolTemplateArgsDict']] template: Node pool template
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: KubeNodePoolArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a nodepool in a OVHcloud Managed Kubernetes Service cluster.

        ## Example Usage

        Create a simple node pool in your Kubernetes cluster:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        node_pool = ovh.cloud_project.KubeNodePool("node_pool",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            kube_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            name="my-pool-1",
            flavor_name="b2-7",
            desired_nodes=3,
            max_nodes=3,
            min_nodes=3)
        ```

        Create an advanced node pool in your Kubernetes cluster:

        ```python
        import pulumi
        import pulumi_ovh as ovh

        pool = ovh.cloud_project.KubeNodePool("pool",
            service_name="xxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
            kube_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            name="my-pool",
            flavor_name="b2-7",
            desired_nodes=3,
            max_nodes=3,
            min_nodes=3,
            template={
                "metadata": {
                    "annotations": {
                        "k1": "v1",
                        "k2": "v2",
                    },
                    "finalizers": [],
                    "labels": {
                        "k3": "v3",
                        "k4": "v4",
                    },
                },
                "spec": {
                    "unschedulable": False,
                    "taints": [{
                        "effect": "PreferNoSchedule",
                        "key": "k",
                        "value": "v",
                    }],
                },
            })
        ```

        ## Import

        OVHcloud Managed Kubernetes Service cluster node pool can be imported using the `service_name`, the `id` of the cluster, and the `id` of the nodepool separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/kubeNodePool:KubeNodePool pool service_name/kube_id/poolid
        ```

        :param str resource_name: The name of the resource.
        :param KubeNodePoolArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(KubeNodePoolArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 anti_affinity: Optional[pulumi.Input[builtins.bool]] = None,
                 autoscale: Optional[pulumi.Input[builtins.bool]] = None,
                 autoscaling_scale_down_unneeded_time_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 autoscaling_scale_down_unready_time_seconds: Optional[pulumi.Input[builtins.int]] = None,
                 autoscaling_scale_down_utilization_threshold: Optional[pulumi.Input[builtins.float]] = None,
                 desired_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 flavor_name: Optional[pulumi.Input[builtins.str]] = None,
                 kube_id: Optional[pulumi.Input[builtins.str]] = None,
                 max_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 min_nodes: Optional[pulumi.Input[builtins.int]] = None,
                 monthly_billed: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 template: Optional[pulumi.Input[Union['KubeNodePoolTemplateArgs', 'KubeNodePoolTemplateArgsDict']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = KubeNodePoolArgs.__new__(KubeNodePoolArgs)

            __props__.__dict__["anti_affinity"] = anti_affinity
            __props__.__dict__["autoscale"] = autoscale
            __props__.__dict__["autoscaling_scale_down_unneeded_time_seconds"] = autoscaling_scale_down_unneeded_time_seconds
            __props__.__dict__["autoscaling_scale_down_unready_time_seconds"] = autoscaling_scale_down_unready_time_seconds
            __props__.__dict__["autoscaling_scale_down_utilization_threshold"] = autoscaling_scale_down_utilization_threshold
            __props__.__dict__["desired_nodes"] = desired_nodes
            if flavor_name is None and not opts.urn:
                raise TypeError("Missing required property 'flavor_name'")
            __props__.__dict__["flavor_name"] = flavor_name
            if kube_id is None and not opts.urn:
                raise TypeError("Missing required property 'kube_id'")
            __props__.__dict__["kube_id"] = kube_id
            __props__.__dict__["max_nodes"] = max_nodes
            __props__.__dict__["min_nodes"] = min_nodes
            __props__.__dict__["monthly_billed"] = monthly_billed
            __props__.__dict__["name"] = name
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["template"] = template
            __props__.__dict__["available_nodes"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["current_nodes"] = None
            __props__.__dict__["flavor"] = None
            __props__.__dict__["project_id"] = None
            __props__.__dict__["size_status"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["up_to_date_nodes"] = None
            __props__.__dict__["updated_at"] = None
        super(KubeNodePool, __self__).__init__(
            'ovh:CloudProject/kubeNodePool:KubeNodePool',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            anti_affinity: Optional[pulumi.Input[builtins.bool]] = None,
            autoscale: Optional[pulumi.Input[builtins.bool]] = None,
            autoscaling_scale_down_unneeded_time_seconds: Optional[pulumi.Input[builtins.int]] = None,
            autoscaling_scale_down_unready_time_seconds: Optional[pulumi.Input[builtins.int]] = None,
            autoscaling_scale_down_utilization_threshold: Optional[pulumi.Input[builtins.float]] = None,
            available_nodes: Optional[pulumi.Input[builtins.int]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            current_nodes: Optional[pulumi.Input[builtins.int]] = None,
            desired_nodes: Optional[pulumi.Input[builtins.int]] = None,
            flavor: Optional[pulumi.Input[builtins.str]] = None,
            flavor_name: Optional[pulumi.Input[builtins.str]] = None,
            kube_id: Optional[pulumi.Input[builtins.str]] = None,
            max_nodes: Optional[pulumi.Input[builtins.int]] = None,
            min_nodes: Optional[pulumi.Input[builtins.int]] = None,
            monthly_billed: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            project_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            size_status: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            template: Optional[pulumi.Input[Union['KubeNodePoolTemplateArgs', 'KubeNodePoolTemplateArgsDict']]] = None,
            up_to_date_nodes: Optional[pulumi.Input[builtins.int]] = None,
            updated_at: Optional[pulumi.Input[builtins.str]] = None) -> 'KubeNodePool':
        """
        Get an existing KubeNodePool resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] anti_affinity: should the pool use the anti-affinity feature. Default to `false`. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.bool] autoscale: Enable auto-scaling for the pool. Default to `false`.
        :param pulumi.Input[builtins.int] autoscaling_scale_down_unneeded_time_seconds: scaleDownUnneededTimeSeconds autoscaling parameter How long a node should be unneeded before it is eligible for scale down
        :param pulumi.Input[builtins.int] autoscaling_scale_down_unready_time_seconds: scaleDownUnreadyTimeSeconds autoscaling parameter How long an unready node should be unneeded before it is eligible for scale down
        :param pulumi.Input[builtins.float] autoscaling_scale_down_utilization_threshold: scaleDownUtilizationThreshold autoscaling parameter Node utilization level, defined as sum of requested resources divided by capacity, below which a node can be considered for scale down
               * `template ` - (Optional) Managed Kubernetes nodepool template, which is a complex object constituted by two main nested objects:
        :param pulumi.Input[builtins.int] available_nodes: Number of nodes which are actually ready in the pool
        :param pulumi.Input[builtins.str] created_at: Creation date
        :param pulumi.Input[builtins.int] current_nodes: Number of nodes present in the pool
        :param pulumi.Input[builtins.int] desired_nodes: number of nodes to start.
        :param pulumi.Input[builtins.str] flavor: Flavor name
        :param pulumi.Input[builtins.str] flavor_name: a valid OVHcloud public cloud flavor ID in which the nodes will be started. Ex: "b2-7". You can find the list of flavor IDs: https://www.ovhcloud.com/fr/public-cloud/prices/. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] kube_id: The id of the managed kubernetes cluster. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.int] max_nodes: maximum number of nodes allowed in the pool. Setting `desired_nodes` over this value will raise an error.
        :param pulumi.Input[builtins.int] min_nodes: minimum number of nodes allowed in the pool. Setting `desired_nodes` under this value will raise an error.
        :param pulumi.Input[builtins.bool] monthly_billed: should the nodes be billed on a monthly basis. Default to `false`. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] name: The name of the nodepool. Warning: `_` char is not allowed! **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] project_id: Project id
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        :param pulumi.Input[builtins.str] size_status: Status describing the state between number of nodes wanted and available ones
        :param pulumi.Input[builtins.str] status: Current status
        :param pulumi.Input[Union['KubeNodePoolTemplateArgs', 'KubeNodePoolTemplateArgsDict']] template: Node pool template
        :param pulumi.Input[builtins.int] up_to_date_nodes: Number of nodes with the latest version installed in the pool
        :param pulumi.Input[builtins.str] updated_at: Last update date
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _KubeNodePoolState.__new__(_KubeNodePoolState)

        __props__.__dict__["anti_affinity"] = anti_affinity
        __props__.__dict__["autoscale"] = autoscale
        __props__.__dict__["autoscaling_scale_down_unneeded_time_seconds"] = autoscaling_scale_down_unneeded_time_seconds
        __props__.__dict__["autoscaling_scale_down_unready_time_seconds"] = autoscaling_scale_down_unready_time_seconds
        __props__.__dict__["autoscaling_scale_down_utilization_threshold"] = autoscaling_scale_down_utilization_threshold
        __props__.__dict__["available_nodes"] = available_nodes
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["current_nodes"] = current_nodes
        __props__.__dict__["desired_nodes"] = desired_nodes
        __props__.__dict__["flavor"] = flavor
        __props__.__dict__["flavor_name"] = flavor_name
        __props__.__dict__["kube_id"] = kube_id
        __props__.__dict__["max_nodes"] = max_nodes
        __props__.__dict__["min_nodes"] = min_nodes
        __props__.__dict__["monthly_billed"] = monthly_billed
        __props__.__dict__["name"] = name
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["size_status"] = size_status
        __props__.__dict__["status"] = status
        __props__.__dict__["template"] = template
        __props__.__dict__["up_to_date_nodes"] = up_to_date_nodes
        __props__.__dict__["updated_at"] = updated_at
        return KubeNodePool(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="antiAffinity")
    def anti_affinity(self) -> pulumi.Output[builtins.bool]:
        """
        should the pool use the anti-affinity feature. Default to `false`. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "anti_affinity")

    @property
    @pulumi.getter
    def autoscale(self) -> pulumi.Output[builtins.bool]:
        """
        Enable auto-scaling for the pool. Default to `false`.
        """
        return pulumi.get(self, "autoscale")

    @property
    @pulumi.getter(name="autoscalingScaleDownUnneededTimeSeconds")
    def autoscaling_scale_down_unneeded_time_seconds(self) -> pulumi.Output[builtins.int]:
        """
        scaleDownUnneededTimeSeconds autoscaling parameter How long a node should be unneeded before it is eligible for scale down
        """
        return pulumi.get(self, "autoscaling_scale_down_unneeded_time_seconds")

    @property
    @pulumi.getter(name="autoscalingScaleDownUnreadyTimeSeconds")
    def autoscaling_scale_down_unready_time_seconds(self) -> pulumi.Output[builtins.int]:
        """
        scaleDownUnreadyTimeSeconds autoscaling parameter How long an unready node should be unneeded before it is eligible for scale down
        """
        return pulumi.get(self, "autoscaling_scale_down_unready_time_seconds")

    @property
    @pulumi.getter(name="autoscalingScaleDownUtilizationThreshold")
    def autoscaling_scale_down_utilization_threshold(self) -> pulumi.Output[builtins.float]:
        """
        scaleDownUtilizationThreshold autoscaling parameter Node utilization level, defined as sum of requested resources divided by capacity, below which a node can be considered for scale down
        * `template ` - (Optional) Managed Kubernetes nodepool template, which is a complex object constituted by two main nested objects:
        """
        return pulumi.get(self, "autoscaling_scale_down_utilization_threshold")

    @property
    @pulumi.getter(name="availableNodes")
    def available_nodes(self) -> pulumi.Output[builtins.int]:
        """
        Number of nodes which are actually ready in the pool
        """
        return pulumi.get(self, "available_nodes")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Creation date
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter(name="currentNodes")
    def current_nodes(self) -> pulumi.Output[builtins.int]:
        """
        Number of nodes present in the pool
        """
        return pulumi.get(self, "current_nodes")

    @property
    @pulumi.getter(name="desiredNodes")
    def desired_nodes(self) -> pulumi.Output[builtins.int]:
        """
        number of nodes to start.
        """
        return pulumi.get(self, "desired_nodes")

    @property
    @pulumi.getter
    def flavor(self) -> pulumi.Output[builtins.str]:
        """
        Flavor name
        """
        return pulumi.get(self, "flavor")

    @property
    @pulumi.getter(name="flavorName")
    def flavor_name(self) -> pulumi.Output[builtins.str]:
        """
        a valid OVHcloud public cloud flavor ID in which the nodes will be started. Ex: "b2-7". You can find the list of flavor IDs: https://www.ovhcloud.com/fr/public-cloud/prices/. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "flavor_name")

    @property
    @pulumi.getter(name="kubeId")
    def kube_id(self) -> pulumi.Output[builtins.str]:
        """
        The id of the managed kubernetes cluster. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "kube_id")

    @property
    @pulumi.getter(name="maxNodes")
    def max_nodes(self) -> pulumi.Output[builtins.int]:
        """
        maximum number of nodes allowed in the pool. Setting `desired_nodes` over this value will raise an error.
        """
        return pulumi.get(self, "max_nodes")

    @property
    @pulumi.getter(name="minNodes")
    def min_nodes(self) -> pulumi.Output[builtins.int]:
        """
        minimum number of nodes allowed in the pool. Setting `desired_nodes` under this value will raise an error.
        """
        return pulumi.get(self, "min_nodes")

    @property
    @pulumi.getter(name="monthlyBilled")
    def monthly_billed(self) -> pulumi.Output[builtins.bool]:
        """
        should the nodes be billed on a monthly basis. Default to `false`. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "monthly_billed")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the nodepool. Warning: `_` char is not allowed! **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[builtins.str]:
        """
        Project id
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used. **Changing this value recreates the resource.**
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="sizeStatus")
    def size_status(self) -> pulumi.Output[builtins.str]:
        """
        Status describing the state between number of nodes wanted and available ones
        """
        return pulumi.get(self, "size_status")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Current status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def template(self) -> pulumi.Output[Optional['outputs.KubeNodePoolTemplate']]:
        """
        Node pool template
        """
        return pulumi.get(self, "template")

    @property
    @pulumi.getter(name="upToDateNodes")
    def up_to_date_nodes(self) -> pulumi.Output[builtins.int]:
        """
        Number of nodes with the latest version installed in the pool
        """
        return pulumi.get(self, "up_to_date_nodes")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[builtins.str]:
        """
        Last update date
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['MongoDbUserArgs', 'MongoDbUser']

@pulumi.input_type
class MongoDbUserArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password_reset: Optional[pulumi.Input[builtins.str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a MongoDbUser resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] name: Name of the user. A user named "admin" is mapped with already created admin@admin user instead of creating a new user.
        :param pulumi.Input[builtins.str] password_reset: Arbitrary string to change to trigger a password update
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] roles: Roles the user belongs to. Since version 0.37.0, the authentication database must be indicated for all roles. Available roles:
               * `backup@admin`
               * `clusterAdmin@admin`
               * `clusterManager@admin`
               * `clusterMonitor@admin`
               * `dbAdmin@(defined db)`
               * `dbAdminAnyDatabase@admin`
               * `dbOwner@(defined db)`
               * `enableSharding@(defined db)`
               * `hostManager@admin`
               * `read@(defined db)`
               * `readAnyDatabase@admin`
               * `readWrite@(defined db)`
               * `readWriteAnyDatabase@admin`
               * `restore@admin`
               * `root@admin`
               * `userAdmin@(defined db)`
               * `userAdminAnyDatabase@admin`
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "service_name", service_name)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password_reset is not None:
            pulumi.set(__self__, "password_reset", password_reset)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the user. A user named "admin" is mapped with already created admin@admin user instead of creating a new user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="passwordReset")
    def password_reset(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Arbitrary string to change to trigger a password update
        """
        return pulumi.get(self, "password_reset")

    @password_reset.setter
    def password_reset(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password_reset", value)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Roles the user belongs to. Since version 0.37.0, the authentication database must be indicated for all roles. Available roles:
        * `backup@admin`
        * `clusterAdmin@admin`
        * `clusterManager@admin`
        * `clusterMonitor@admin`
        * `dbAdmin@(defined db)`
        * `dbAdminAnyDatabase@admin`
        * `dbOwner@(defined db)`
        * `enableSharding@(defined db)`
        * `hostManager@admin`
        * `read@(defined db)`
        * `readAnyDatabase@admin`
        * `readWrite@(defined db)`
        * `readWriteAnyDatabase@admin`
        * `restore@admin`
        * `root@admin`
        * `userAdmin@(defined db)`
        * `userAdminAnyDatabase@admin`
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "roles", value)


@pulumi.input_type
class _MongoDbUserState:
    def __init__(__self__, *,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 created_at: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password: Optional[pulumi.Input[builtins.str]] = None,
                 password_reset: Optional[pulumi.Input[builtins.str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering MongoDbUser resources.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] created_at: Date of the creation of the user.
        :param pulumi.Input[builtins.str] name: Name of the user. A user named "admin" is mapped with already created admin@admin user instead of creating a new user.
        :param pulumi.Input[builtins.str] password: (Sensitive) Password of the user.
        :param pulumi.Input[builtins.str] password_reset: Arbitrary string to change to trigger a password update
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] roles: Roles the user belongs to. Since version 0.37.0, the authentication database must be indicated for all roles. Available roles:
               * `backup@admin`
               * `clusterAdmin@admin`
               * `clusterManager@admin`
               * `clusterMonitor@admin`
               * `dbAdmin@(defined db)`
               * `dbAdminAnyDatabase@admin`
               * `dbOwner@(defined db)`
               * `enableSharding@(defined db)`
               * `hostManager@admin`
               * `read@(defined db)`
               * `readAnyDatabase@admin`
               * `readWrite@(defined db)`
               * `readWriteAnyDatabase@admin`
               * `restore@admin`
               * `root@admin`
               * `userAdmin@(defined db)`
               * `userAdminAnyDatabase@admin`
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] status: Current status of the user.
        """
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if password is not None:
            pulumi.set(__self__, "password", password)
        if password_reset is not None:
            pulumi.set(__self__, "password_reset", password_reset)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Date of the creation of the user.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Name of the user. A user named "admin" is mapped with already created admin@admin user instead of creating a new user.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def password(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        (Sensitive) Password of the user.
        """
        return pulumi.get(self, "password")

    @password.setter
    def password(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password", value)

    @property
    @pulumi.getter(name="passwordReset")
    def password_reset(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Arbitrary string to change to trigger a password update
        """
        return pulumi.get(self, "password_reset")

    @password_reset.setter
    def password_reset(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "password_reset", value)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Roles the user belongs to. Since version 0.37.0, the authentication database must be indicated for all roles. Available roles:
        * `backup@admin`
        * `clusterAdmin@admin`
        * `clusterManager@admin`
        * `clusterMonitor@admin`
        * `dbAdmin@(defined db)`
        * `dbAdminAnyDatabase@admin`
        * `dbOwner@(defined db)`
        * `enableSharding@(defined db)`
        * `hostManager@admin`
        * `read@(defined db)`
        * `readAnyDatabase@admin`
        * `readWrite@(defined db)`
        * `readWriteAnyDatabase@admin`
        * `restore@admin`
        * `root@admin`
        * `userAdmin@(defined db)`
        * `userAdminAnyDatabase@admin`
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Current status of the user.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)


class MongoDbUser(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password_reset: Optional[pulumi.Input[builtins.str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        ## Import

        OVHcloud Managed MongoDB clusters users can be imported using the `service_name`, `cluster_id` and `id` of the user, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/mongoDbUser:MongoDbUser my_user service_name/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] name: Name of the user. A user named "admin" is mapped with already created admin@admin user instead of creating a new user.
        :param pulumi.Input[builtins.str] password_reset: Arbitrary string to change to trigger a password update
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] roles: Roles the user belongs to. Since version 0.37.0, the authentication database must be indicated for all roles. Available roles:
               * `backup@admin`
               * `clusterAdmin@admin`
               * `clusterManager@admin`
               * `clusterMonitor@admin`
               * `dbAdmin@(defined db)`
               * `dbAdminAnyDatabase@admin`
               * `dbOwner@(defined db)`
               * `enableSharding@(defined db)`
               * `hostManager@admin`
               * `read@(defined db)`
               * `readAnyDatabase@admin`
               * `readWrite@(defined db)`
               * `readWriteAnyDatabase@admin`
               * `restore@admin`
               * `root@admin`
               * `userAdmin@(defined db)`
               * `userAdminAnyDatabase@admin`
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: MongoDbUserArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        OVHcloud Managed MongoDB clusters users can be imported using the `service_name`, `cluster_id` and `id` of the user, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProjectDatabase/mongoDbUser:MongoDbUser my_user service_name/cluster_id/id
        ```

        :param str resource_name: The name of the resource.
        :param MongoDbUserArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(MongoDbUserArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 password_reset: Optional[pulumi.Input[builtins.str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = MongoDbUserArgs.__new__(MongoDbUserArgs)

            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["name"] = name
            __props__.__dict__["password_reset"] = password_reset
            __props__.__dict__["roles"] = roles
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["created_at"] = None
            __props__.__dict__["password"] = None
            __props__.__dict__["status"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["password"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(MongoDbUser, __self__).__init__(
            'ovh:CloudProjectDatabase/mongoDbUser:MongoDbUser',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            created_at: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            password: Optional[pulumi.Input[builtins.str]] = None,
            password_reset: Optional[pulumi.Input[builtins.str]] = None,
            roles: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None) -> 'MongoDbUser':
        """
        Get an existing MongoDbUser resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cluster_id: Cluster ID.
        :param pulumi.Input[builtins.str] created_at: Date of the creation of the user.
        :param pulumi.Input[builtins.str] name: Name of the user. A user named "admin" is mapped with already created admin@admin user instead of creating a new user.
        :param pulumi.Input[builtins.str] password: (Sensitive) Password of the user.
        :param pulumi.Input[builtins.str] password_reset: Arbitrary string to change to trigger a password update
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] roles: Roles the user belongs to. Since version 0.37.0, the authentication database must be indicated for all roles. Available roles:
               * `backup@admin`
               * `clusterAdmin@admin`
               * `clusterManager@admin`
               * `clusterMonitor@admin`
               * `dbAdmin@(defined db)`
               * `dbAdminAnyDatabase@admin`
               * `dbOwner@(defined db)`
               * `enableSharding@(defined db)`
               * `hostManager@admin`
               * `read@(defined db)`
               * `readAnyDatabase@admin`
               * `readWrite@(defined db)`
               * `readWriteAnyDatabase@admin`
               * `restore@admin`
               * `root@admin`
               * `userAdmin@(defined db)`
               * `userAdminAnyDatabase@admin`
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] status: Current status of the user.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _MongoDbUserState.__new__(_MongoDbUserState)

        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["name"] = name
        __props__.__dict__["password"] = password
        __props__.__dict__["password_reset"] = password_reset
        __props__.__dict__["roles"] = roles
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["status"] = status
        return MongoDbUser(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        Cluster ID.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[builtins.str]:
        """
        Date of the creation of the user.
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Name of the user. A user named "admin" is mapped with already created admin@admin user instead of creating a new user.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def password(self) -> pulumi.Output[builtins.str]:
        """
        (Sensitive) Password of the user.
        """
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordReset")
    def password_reset(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Arbitrary string to change to trigger a password update
        """
        return pulumi.get(self, "password_reset")

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Roles the user belongs to. Since version 0.37.0, the authentication database must be indicated for all roles. Available roles:
        * `backup@admin`
        * `clusterAdmin@admin`
        * `clusterManager@admin`
        * `clusterMonitor@admin`
        * `dbAdmin@(defined db)`
        * `dbAdminAnyDatabase@admin`
        * `dbOwner@(defined db)`
        * `enableSharding@(defined db)`
        * `hostManager@admin`
        * `read@(defined db)`
        * `readAnyDatabase@admin`
        * `readWrite@(defined db)`
        * `readWriteAnyDatabase@admin`
        * `restore@admin`
        * `root@admin`
        * `userAdmin@(defined db)`
        * `userAdminAnyDatabase@admin`
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Current status of the user.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ReverseArgs', 'Reverse']

@pulumi.input_type
class ReverseArgs:
    def __init__(__self__, *,
                 reverse_ip: pulumi.Input[builtins.str],
                 reverse_value: pulumi.Input[builtins.str],
                 ip: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a Reverse resource.
        :param pulumi.Input[builtins.str] reverse_ip: The IP to set the reverse of
        :param pulumi.Input[builtins.str] reverse_value: The value of the reverse
        :param pulumi.Input[builtins.str] ip: The IP block to which the IP belongs
        """
        pulumi.set(__self__, "reverse_ip", reverse_ip)
        pulumi.set(__self__, "reverse_value", reverse_value)
        pulumi.set(__self__, "ip", ip)

    @property
    @pulumi.getter(name="ReverseIp")
    def reverse_ip(self) -> pulumi.Input[builtins.str]:
        """
        The IP to set the reverse of
        """
        return pulumi.get(self, "reverse_ip")

    @reverse_ip.setter
    def reverse_ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "reverse_ip", value)

    @property
    @pulumi.getter(name="ReverseValue")
    def reverse_value(self) -> pulumi.Input[builtins.str]:
        """
        The value of the reverse
        """
        return pulumi.get(self, "reverse_value")

    @reverse_value.setter
    def reverse_value(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "reverse_value", value)

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Input[builtins.str]:
        """
        The IP block to which the IP belongs
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "ip", value)


@pulumi.input_type
class _ReverseState:
    def __init__(__self__, *,
                 reverse_ip: Optional[pulumi.Input[builtins.str]] = None,
                 reverse_value: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Reverse resources.
        :param pulumi.Input[builtins.str] reverse_ip: The IP to set the reverse of
        :param pulumi.Input[builtins.str] reverse_value: The value of the reverse
        :param pulumi.Input[builtins.str] ip: The IP block to which the IP belongs
        """
        if reverse_ip is not None:
            pulumi.set(__self__, "reverse_ip", reverse_ip)
        if reverse_value is not None:
            pulumi.set(__self__, "reverse_value", reverse_value)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)

    @property
    @pulumi.getter(name="ReverseIp")
    def reverse_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IP to set the reverse of
        """
        return pulumi.get(self, "reverse_ip")

    @reverse_ip.setter
    def reverse_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "reverse_ip", value)

    @property
    @pulumi.getter(name="ReverseValue")
    def reverse_value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The value of the reverse
        """
        return pulumi.get(self, "reverse_value")

    @reverse_value.setter
    def reverse_value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "reverse_value", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IP block to which the IP belongs
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)


class Reverse(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 reverse_ip: Optional[pulumi.Input[builtins.str]] = None,
                 reverse_value: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Provides a OVHcloud IP reverse.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        # Set the reverse of an IP
        test = ovh.ip.Reverse("test",
            ip="192.0.2.0/24",
            reverse_ip="192.0.2.1",
            reverse_value="example.com")
        ```

        ## Import

        The resource can be imported using the `ip`, `ip_reverse` of the address, separated by "|" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Ip/reverse:Reverse my_reverse '2001:0db8:c0ff:ee::/64|2001:0db8:c0ff:ee::42'
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] reverse_ip: The IP to set the reverse of
        :param pulumi.Input[builtins.str] reverse_value: The value of the reverse
        :param pulumi.Input[builtins.str] ip: The IP block to which the IP belongs
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ReverseArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a OVHcloud IP reverse.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        # Set the reverse of an IP
        test = ovh.ip.Reverse("test",
            ip="192.0.2.0/24",
            reverse_ip="192.0.2.1",
            reverse_value="example.com")
        ```

        ## Import

        The resource can be imported using the `ip`, `ip_reverse` of the address, separated by "|" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Ip/reverse:Reverse my_reverse '2001:0db8:c0ff:ee::/64|2001:0db8:c0ff:ee::42'
        ```

        :param str resource_name: The name of the resource.
        :param ReverseArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ReverseArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 reverse_ip: Optional[pulumi.Input[builtins.str]] = None,
                 reverse_value: Optional[pulumi.Input[builtins.str]] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ReverseArgs.__new__(ReverseArgs)

            if reverse_ip is None and not opts.urn:
                raise TypeError("Missing required property 'reverse_ip'")
            __props__.__dict__["reverse_ip"] = reverse_ip
            if reverse_value is None and not opts.urn:
                raise TypeError("Missing required property 'reverse_value'")
            __props__.__dict__["reverse_value"] = reverse_value
            if ip is None and not opts.urn:
                raise TypeError("Missing required property 'ip'")
            __props__.__dict__["ip"] = ip
        super(Reverse, __self__).__init__(
            'ovh:Ip/reverse:Reverse',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            reverse_ip: Optional[pulumi.Input[builtins.str]] = None,
            reverse_value: Optional[pulumi.Input[builtins.str]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None) -> 'Reverse':
        """
        Get an existing Reverse resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] reverse_ip: The IP to set the reverse of
        :param pulumi.Input[builtins.str] reverse_value: The value of the reverse
        :param pulumi.Input[builtins.str] ip: The IP block to which the IP belongs
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ReverseState.__new__(_ReverseState)

        __props__.__dict__["reverse_ip"] = reverse_ip
        __props__.__dict__["reverse_value"] = reverse_value
        __props__.__dict__["ip"] = ip
        return Reverse(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="ReverseIp")
    def reverse_ip(self) -> pulumi.Output[builtins.str]:
        """
        The IP to set the reverse of
        """
        return pulumi.get(self, "reverse_ip")

    @property
    @pulumi.getter(name="ReverseValue")
    def reverse_value(self) -> pulumi.Output[builtins.str]:
        """
        The value of the reverse
        """
        return pulumi.get(self, "reverse_value")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        The IP block to which the IP belongs
        """
        return pulumi.get(self, "ip")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['LogsRolePermissionStreamArgs', 'LogsRolePermissionStream']

@pulumi.input_type
class LogsRolePermissionStreamArgs:
    def __init__(__self__, *,
                 role_id: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 stream_id: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a LogsRolePermissionStream resource.
        :param pulumi.Input[builtins.str] role_id: The DBaaS Logs role id
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] stream_id: The DBaaS Logs Graylog output stream id
        """
        pulumi.set(__self__, "role_id", role_id)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "stream_id", stream_id)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Input[builtins.str]:
        """
        The DBaaS Logs role id
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> pulumi.Input[builtins.str]:
        """
        The DBaaS Logs Graylog output stream id
        """
        return pulumi.get(self, "stream_id")

    @stream_id.setter
    def stream_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "stream_id", value)


@pulumi.input_type
class _LogsRolePermissionStreamState:
    def __init__(__self__, *,
                 permission_id: Optional[pulumi.Input[builtins.str]] = None,
                 permission_type: Optional[pulumi.Input[builtins.str]] = None,
                 role_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering LogsRolePermissionStream resources.
        :param pulumi.Input[builtins.str] permission_id: Permission ID
        :param pulumi.Input[builtins.str] permission_type: Permission type (e.g., READ_ONLY)
        :param pulumi.Input[builtins.str] role_id: The DBaaS Logs role id
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] stream_id: The DBaaS Logs Graylog output stream id
        """
        if permission_id is not None:
            pulumi.set(__self__, "permission_id", permission_id)
        if permission_type is not None:
            pulumi.set(__self__, "permission_type", permission_type)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if stream_id is not None:
            pulumi.set(__self__, "stream_id", stream_id)

    @property
    @pulumi.getter(name="permissionId")
    def permission_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Permission ID
        """
        return pulumi.get(self, "permission_id")

    @permission_id.setter
    def permission_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_id", value)

    @property
    @pulumi.getter(name="permissionType")
    def permission_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Permission type (e.g., READ_ONLY)
        """
        return pulumi.get(self, "permission_type")

    @permission_type.setter
    def permission_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "permission_type", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The DBaaS Logs role id
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The DBaaS Logs Graylog output stream id
        """
        return pulumi.get(self, "stream_id")

    @stream_id.setter
    def stream_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "stream_id", value)


class LogsRolePermissionStream(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 role_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Reference a DBaaS logs role stream permission.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        permission = ovh.dbaas.LogsRolePermissionStream("permission",
            service_name="ldp-xx-xxxxx",
            role_id=ro["id"],
            stream_id=mystream["streamId"])
        ```

        ## Import

        DBaaS logs role stream permission can be imported using the `service_name`, `role_id` and `id` of the permission, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Dbaas/logsRolePermissionStream:LogsRolePermissionStream  ovh_dbaas_logs_role_permission_stream.perm ldp-ra-XX/dc145bc2-eb01-4efe-a802-XXXXXX/e4818fa8-f426-11ef-a1f6-XXXXXXX
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] role_id: The DBaaS Logs role id
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] stream_id: The DBaaS Logs Graylog output stream id
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LogsRolePermissionStreamArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Reference a DBaaS logs role stream permission.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        permission = ovh.dbaas.LogsRolePermissionStream("permission",
            service_name="ldp-xx-xxxxx",
            role_id=ro["id"],
            stream_id=mystream["streamId"])
        ```

        ## Import

        DBaaS logs role stream permission can be imported using the `service_name`, `role_id` and `id` of the permission, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:Dbaas/logsRolePermissionStream:LogsRolePermissionStream  ovh_dbaas_logs_role_permission_stream.perm ldp-ra-XX/dc145bc2-eb01-4efe-a802-XXXXXX/e4818fa8-f426-11ef-a1f6-XXXXXXX
        ```

        :param str resource_name: The name of the resource.
        :param LogsRolePermissionStreamArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LogsRolePermissionStreamArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 role_id: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 stream_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LogsRolePermissionStreamArgs.__new__(LogsRolePermissionStreamArgs)

            if role_id is None and not opts.urn:
                raise TypeError("Missing required property 'role_id'")
            __props__.__dict__["role_id"] = role_id
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if stream_id is None and not opts.urn:
                raise TypeError("Missing required property 'stream_id'")
            __props__.__dict__["stream_id"] = stream_id
            __props__.__dict__["permission_id"] = None
            __props__.__dict__["permission_type"] = None
        super(LogsRolePermissionStream, __self__).__init__(
            'ovh:Dbaas/logsRolePermissionStream:LogsRolePermissionStream',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            permission_id: Optional[pulumi.Input[builtins.str]] = None,
            permission_type: Optional[pulumi.Input[builtins.str]] = None,
            role_id: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            stream_id: Optional[pulumi.Input[builtins.str]] = None) -> 'LogsRolePermissionStream':
        """
        Get an existing LogsRolePermissionStream resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] permission_id: Permission ID
        :param pulumi.Input[builtins.str] permission_type: Permission type (e.g., READ_ONLY)
        :param pulumi.Input[builtins.str] role_id: The DBaaS Logs role id
        :param pulumi.Input[builtins.str] service_name: The service name
        :param pulumi.Input[builtins.str] stream_id: The DBaaS Logs Graylog output stream id
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LogsRolePermissionStreamState.__new__(_LogsRolePermissionStreamState)

        __props__.__dict__["permission_id"] = permission_id
        __props__.__dict__["permission_type"] = permission_type
        __props__.__dict__["role_id"] = role_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["stream_id"] = stream_id
        return LogsRolePermissionStream(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="permissionId")
    def permission_id(self) -> pulumi.Output[builtins.str]:
        """
        Permission ID
        """
        return pulumi.get(self, "permission_id")

    @property
    @pulumi.getter(name="permissionType")
    def permission_type(self) -> pulumi.Output[builtins.str]:
        """
        Permission type (e.g., READ_ONLY)
        """
        return pulumi.get(self, "permission_type")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[builtins.str]:
        """
        The DBaaS Logs role id
        """
        return pulumi.get(self, "role_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="streamId")
    def stream_id(self) -> pulumi.Output[builtins.str]:
        """
        The DBaaS Logs Graylog output stream id
        """
        return pulumi.get(self, "stream_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetContainerRegistryResult',
    'AwaitableGetContainerRegistryResult',
    'get_container_registry',
    'get_container_registry_output',
]

@pulumi.output_type
class GetContainerRegistryResult:
    """
    A collection of values returned by getContainerRegistry.
    """
    def __init__(__self__, created_at=None, id=None, name=None, project_id=None, region=None, registry_id=None, service_name=None, size=None, status=None, updated_at=None, url=None, version=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if registry_id and not isinstance(registry_id, str):
            raise TypeError("Expected argument 'registry_id' to be a str")
        pulumi.set(__self__, "registry_id", registry_id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if size and not isinstance(size, int):
            raise TypeError("Expected argument 'size' to be a int")
        pulumi.set(__self__, "size", size)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if url and not isinstance(url, str):
            raise TypeError("Expected argument 'url' to be a str")
        pulumi.set(__self__, "url", url)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        Registry creation date
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Registry name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="projectId")
    def project_id(self) -> builtins.str:
        """
        Project ID of your registry
        """
        return pulumi.get(self, "project_id")

    @property
    @pulumi.getter
    def region(self) -> builtins.str:
        """
        Region of the registry
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="registryId")
    def registry_id(self) -> builtins.str:
        return pulumi.get(self, "registry_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def size(self) -> builtins.int:
        """
        Current size of the registry (bytes)
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Registry status
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        Registry last update date
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def url(self) -> builtins.str:
        """
        Access url of the registry
        """
        return pulumi.get(self, "url")

    @property
    @pulumi.getter
    def version(self) -> builtins.str:
        """
        Version of your registry
        """
        return pulumi.get(self, "version")


class AwaitableGetContainerRegistryResult(GetContainerRegistryResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetContainerRegistryResult(
            created_at=self.created_at,
            id=self.id,
            name=self.name,
            project_id=self.project_id,
            region=self.region,
            registry_id=self.registry_id,
            service_name=self.service_name,
            size=self.size,
            status=self.status,
            updated_at=self.updated_at,
            url=self.url,
            version=self.version)


def get_container_registry(registry_id: Optional[builtins.str] = None,
                           service_name: Optional[builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetContainerRegistryResult:
    """
    Use this data source to get information about a container registry associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_registry = ovh.CloudProject.get_container_registry(service_name="XXXXXX",
        registry_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx")
    ```


    :param builtins.str registry_id: Registry ID
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['registryId'] = registry_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProject/getContainerRegistry:getContainerRegistry', __args__, opts=opts, typ=GetContainerRegistryResult).value

    return AwaitableGetContainerRegistryResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        registry_id=pulumi.get(__ret__, 'registry_id'),
        service_name=pulumi.get(__ret__, 'service_name'),
        size=pulumi.get(__ret__, 'size'),
        status=pulumi.get(__ret__, 'status'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        url=pulumi.get(__ret__, 'url'),
        version=pulumi.get(__ret__, 'version'))
def get_container_registry_output(registry_id: Optional[pulumi.Input[builtins.str]] = None,
                                  service_name: Optional[pulumi.Input[builtins.str]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetContainerRegistryResult]:
    """
    Use this data source to get information about a container registry associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    my_registry = ovh.CloudProject.get_container_registry(service_name="XXXXXX",
        registry_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxx")
    ```


    :param builtins.str registry_id: Registry ID
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['registryId'] = registry_id
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProject/getContainerRegistry:getContainerRegistry', __args__, opts=opts, typ=GetContainerRegistryResult)
    return __ret__.apply(lambda __response__: GetContainerRegistryResult(
        created_at=pulumi.get(__response__, 'created_at'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        registry_id=pulumi.get(__response__, 'registry_id'),
        service_name=pulumi.get(__response__, 'service_name'),
        size=pulumi.get(__response__, 'size'),
        status=pulumi.get(__response__, 'status'),
        updated_at=pulumi.get(__response__, 'updated_at'),
        url=pulumi.get(__response__, 'url'),
        version=pulumi.get(__response__, 'version')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['VolumeBackupArgs', 'VolumeBackup']

@pulumi.input_type
class VolumeBackupArgs:
    def __init__(__self__, *,
                 region_name: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 volume_id: pulumi.Input[builtins.str],
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a VolumeBackup resource.
        :param pulumi.Input[builtins.str] region_name: Region name
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.str] volume_id: ID of the volume to backup
        :param pulumi.Input[builtins.str] name: name of the backup
        """
        pulumi.set(__self__, "region_name", region_name)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "volume_id", volume_id)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Input[builtins.str]:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "region_name", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> pulumi.Input[builtins.str]:
        """
        ID of the volume to backup
        """
        return pulumi.get(self, "volume_id")

    @volume_id.setter
    def volume_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "volume_id", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        name of the backup
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _VolumeBackupState:
    def __init__(__self__, *,
                 creation_date: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.float]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 volume_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering VolumeBackup resources.
        :param pulumi.Input[builtins.str] creation_date: Creation date of the backup
        :param pulumi.Input[builtins.str] name: name of the backup
        :param pulumi.Input[builtins.str] region: Volume backup region
        :param pulumi.Input[builtins.str] region_name: Region name
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.float] size: Size of the backup in GiB
        :param pulumi.Input[builtins.str] status: Staus of the backup
        :param pulumi.Input[builtins.str] volume_id: ID of the volume to backup
        """
        if creation_date is not None:
            pulumi.set(__self__, "creation_date", creation_date)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if region_name is not None:
            pulumi.set(__self__, "region_name", region_name)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if volume_id is not None:
            pulumi.set(__self__, "volume_id", volume_id)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Creation date of the backup
        """
        return pulumi.get(self, "creation_date")

    @creation_date.setter
    def creation_date(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "creation_date", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        name of the backup
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Volume backup region
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @region_name.setter
    def region_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region_name", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Size of the backup in GiB
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Staus of the backup
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        ID of the volume to backup
        """
        return pulumi.get(self, "volume_id")

    @volume_id.setter
    def volume_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "volume_id", value)


class VolumeBackup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 volume_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Manage backups for the given volume in a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        backup = ovh.cloud_project.VolumeBackup("backup",
            service_name="<public cloud project ID>",
            region_name="GRA9",
            volume_id="<volume ID>",
            name="ExampleBackup")
        ```

        ## Import

        A volume backup in a public cloud project can be imported using the `service_name`, `region_name` and `id` attributes. Using the following configuration:

        terraform

        import {

          id = "<service_name>/<region_name>/<id>"

          to = ovh_cloud_project_volume_backup.backup

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=backup.tf

        $ pulumi up

        The file `backup.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] name: name of the backup
        :param pulumi.Input[builtins.str] region_name: Region name
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.str] volume_id: ID of the volume to backup
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VolumeBackupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Manage backups for the given volume in a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        backup = ovh.cloud_project.VolumeBackup("backup",
            service_name="<public cloud project ID>",
            region_name="GRA9",
            volume_id="<volume ID>",
            name="ExampleBackup")
        ```

        ## Import

        A volume backup in a public cloud project can be imported using the `service_name`, `region_name` and `id` attributes. Using the following configuration:

        terraform

        import {

          id = "<service_name>/<region_name>/<id>"

          to = ovh_cloud_project_volume_backup.backup

        }

        You can then run:

        bash

        $ pulumi preview -generate-config-out=backup.tf

        $ pulumi up

        The file `backup.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param VolumeBackupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VolumeBackupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 region_name: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 volume_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VolumeBackupArgs.__new__(VolumeBackupArgs)

            __props__.__dict__["name"] = name
            if region_name is None and not opts.urn:
                raise TypeError("Missing required property 'region_name'")
            __props__.__dict__["region_name"] = region_name
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if volume_id is None and not opts.urn:
                raise TypeError("Missing required property 'volume_id'")
            __props__.__dict__["volume_id"] = volume_id
            __props__.__dict__["creation_date"] = None
            __props__.__dict__["region"] = None
            __props__.__dict__["size"] = None
            __props__.__dict__["status"] = None
        super(VolumeBackup, __self__).__init__(
            'ovh:CloudProject/volumeBackup:VolumeBackup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            creation_date: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            region_name: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            size: Optional[pulumi.Input[builtins.float]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            volume_id: Optional[pulumi.Input[builtins.str]] = None) -> 'VolumeBackup':
        """
        Get an existing VolumeBackup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] creation_date: Creation date of the backup
        :param pulumi.Input[builtins.str] name: name of the backup
        :param pulumi.Input[builtins.str] region: Volume backup region
        :param pulumi.Input[builtins.str] region_name: Region name
        :param pulumi.Input[builtins.str] service_name: Service name
        :param pulumi.Input[builtins.float] size: Size of the backup in GiB
        :param pulumi.Input[builtins.str] status: Staus of the backup
        :param pulumi.Input[builtins.str] volume_id: ID of the volume to backup
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VolumeBackupState.__new__(_VolumeBackupState)

        __props__.__dict__["creation_date"] = creation_date
        __props__.__dict__["name"] = name
        __props__.__dict__["region"] = region
        __props__.__dict__["region_name"] = region_name
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["size"] = size
        __props__.__dict__["status"] = status
        __props__.__dict__["volume_id"] = volume_id
        return VolumeBackup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> pulumi.Output[builtins.str]:
        """
        Creation date of the backup
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        name of the backup
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        Volume backup region
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="regionName")
    def region_name(self) -> pulumi.Output[builtins.str]:
        """
        Region name
        """
        return pulumi.get(self, "region_name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        Service name
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[builtins.float]:
        """
        Size of the backup in GiB
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        Staus of the backup
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="volumeId")
    def volume_id(self) -> pulumi.Output[builtins.str]:
        """
        ID of the volume to backup
        """
        return pulumi.get(self, "volume_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['NasHAPartitionArgs', 'NasHAPartition']

@pulumi.input_type
class NasHAPartitionArgs:
    def __init__(__self__, *,
                 protocol: pulumi.Input[builtins.str],
                 service_name: pulumi.Input[builtins.str],
                 size: pulumi.Input[builtins.int],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a NasHAPartition resource.
        :param pulumi.Input[builtins.str] protocol: one of "NFS", "CIFS" or "NFS_CIFS"
        :param pulumi.Input[builtins.str] service_name: The internal name of your HA-NAS (it has to be ordered via OVHcloud interface)
        :param pulumi.Input[builtins.int] size: size of the partition in GB
        :param pulumi.Input[builtins.str] description: A brief description of the partition
        :param pulumi.Input[builtins.str] name: name of the partition
        """
        pulumi.set(__self__, "protocol", protocol)
        pulumi.set(__self__, "service_name", service_name)
        pulumi.set(__self__, "size", size)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Input[builtins.str]:
        """
        one of "NFS", "CIFS" or "NFS_CIFS"
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Input[builtins.str]:
        """
        The internal name of your HA-NAS (it has to be ordered via OVHcloud interface)
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def size(self) -> pulumi.Input[builtins.int]:
        """
        size of the partition in GB
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A brief description of the partition
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        name of the partition
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)


@pulumi.input_type
class _NasHAPartitionState:
    def __init__(__self__, *,
                 capacity: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 used_by_snapshots: Optional[pulumi.Input[builtins.int]] = None):
        """
        Input properties used for looking up and filtering NasHAPartition resources.
        :param pulumi.Input[builtins.int] capacity: Percentage of partition space used in %
        :param pulumi.Input[builtins.str] description: A brief description of the partition
        :param pulumi.Input[builtins.str] name: name of the partition
        :param pulumi.Input[builtins.str] protocol: one of "NFS", "CIFS" or "NFS_CIFS"
        :param pulumi.Input[builtins.str] service_name: The internal name of your HA-NAS (it has to be ordered via OVHcloud interface)
        :param pulumi.Input[builtins.int] size: size of the partition in GB
        :param pulumi.Input[builtins.int] used_by_snapshots: Percentage of partition space used by snapshots in %
        """
        if capacity is not None:
            pulumi.set(__self__, "capacity", capacity)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if used_by_snapshots is not None:
            pulumi.set(__self__, "used_by_snapshots", used_by_snapshots)

    @property
    @pulumi.getter
    def capacity(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Percentage of partition space used in %
        """
        return pulumi.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "capacity", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        A brief description of the partition
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        name of the partition
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        one of "NFS", "CIFS" or "NFS_CIFS"
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The internal name of your HA-NAS (it has to be ordered via OVHcloud interface)
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def size(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        size of the partition in GB
        """
        return pulumi.get(self, "size")

    @size.setter
    def size(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "size", value)

    @property
    @pulumi.getter(name="usedBySnapshots")
    def used_by_snapshots(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        Percentage of partition space used by snapshots in %
        """
        return pulumi.get(self, "used_by_snapshots")

    @used_by_snapshots.setter
    def used_by_snapshots(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "used_by_snapshots", value)


class NasHAPartition(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        """
        Provides a resource for managing partitions on HA-NAS services

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_partition = ovh.dedicated.NasHAPartition("my_partition",
            service_name="zpool-12345",
            name="my-partition",
            size=20,
            protocol="NFS")
        ```

        ## Import

        HA-NAS can be imported using the `{service_name}/{name}`, e.g.

        ```sh
        $ pulumi import ovh:Dedicated/nasHAPartition:NasHAPartition my-partition zpool-12345/my-partition`
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: A brief description of the partition
        :param pulumi.Input[builtins.str] name: name of the partition
        :param pulumi.Input[builtins.str] protocol: one of "NFS", "CIFS" or "NFS_CIFS"
        :param pulumi.Input[builtins.str] service_name: The internal name of your HA-NAS (it has to be ordered via OVHcloud interface)
        :param pulumi.Input[builtins.int] size: size of the partition in GB
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NasHAPartitionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a resource for managing partitions on HA-NAS services

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        my_partition = ovh.dedicated.NasHAPartition("my_partition",
            service_name="zpool-12345",
            name="my-partition",
            size=20,
            protocol="NFS")
        ```

        ## Import

        HA-NAS can be imported using the `{service_name}/{name}`, e.g.

        ```sh
        $ pulumi import ovh:Dedicated/nasHAPartition:NasHAPartition my-partition zpool-12345/my-partition`
        ```

        :param str resource_name: The name of the resource.
        :param NasHAPartitionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NasHAPartitionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 size: Optional[pulumi.Input[builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NasHAPartitionArgs.__new__(NasHAPartitionArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            if protocol is None and not opts.urn:
                raise TypeError("Missing required property 'protocol'")
            __props__.__dict__["protocol"] = protocol
            if service_name is None and not opts.urn:
                raise TypeError("Missing required property 'service_name'")
            __props__.__dict__["service_name"] = service_name
            if size is None and not opts.urn:
                raise TypeError("Missing required property 'size'")
            __props__.__dict__["size"] = size
            __props__.__dict__["capacity"] = None
            __props__.__dict__["used_by_snapshots"] = None
        super(NasHAPartition, __self__).__init__(
            'ovh:Dedicated/nasHAPartition:NasHAPartition',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            capacity: Optional[pulumi.Input[builtins.int]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            size: Optional[pulumi.Input[builtins.int]] = None,
            used_by_snapshots: Optional[pulumi.Input[builtins.int]] = None) -> 'NasHAPartition':
        """
        Get an existing NasHAPartition resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] capacity: Percentage of partition space used in %
        :param pulumi.Input[builtins.str] description: A brief description of the partition
        :param pulumi.Input[builtins.str] name: name of the partition
        :param pulumi.Input[builtins.str] protocol: one of "NFS", "CIFS" or "NFS_CIFS"
        :param pulumi.Input[builtins.str] service_name: The internal name of your HA-NAS (it has to be ordered via OVHcloud interface)
        :param pulumi.Input[builtins.int] size: size of the partition in GB
        :param pulumi.Input[builtins.int] used_by_snapshots: Percentage of partition space used by snapshots in %
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NasHAPartitionState.__new__(_NasHAPartitionState)

        __props__.__dict__["capacity"] = capacity
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["size"] = size
        __props__.__dict__["used_by_snapshots"] = used_by_snapshots
        return NasHAPartition(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def capacity(self) -> pulumi.Output[builtins.int]:
        """
        Percentage of partition space used in %
        """
        return pulumi.get(self, "capacity")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        A brief description of the partition
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        name of the partition
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        one of "NFS", "CIFS" or "NFS_CIFS"
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The internal name of your HA-NAS (it has to be ordered via OVHcloud interface)
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def size(self) -> pulumi.Output[builtins.int]:
        """
        size of the partition in GB
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="usedBySnapshots")
    def used_by_snapshots(self) -> pulumi.Output[builtins.int]:
        """
        Percentage of partition space used by snapshots in %
        """
        return pulumi.get(self, "used_by_snapshots")

